# ChaiPy

A developer interface for creating Chat AIs for the Chai app.


## Usage

## Local development

A quick start guide is available [here](https://chai.ml/docs/), with a minimal example available on GitHub 
[here](https://github.com/chai-nexus/chai_py_quickstart).

## Colab Notebook

Alternatively, check out the [notebook](https://colab.research.google.com/drive/1YB6mQkcmisEBIHOjvGnWi0z9lLiaRNT5)! 


## Requirements

Python 3.7 is required due to the usage of `dataclasses`.

Manual workarounds exist (see [here](https://stackoverflow.com/q/1868714)), enabling the potential support of earlier 
versions of Python. Other potential limiting factors include the use of `asyncio.run()`, and of `async` in general.

## Socials

Come join us on [Discord](https://discord.gg/YfrVwBtYWb)!
